#!/usr/bin/env bash

# Copyright 2018 The Knative Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# This script runs the presubmit tests; it is started by prow for each PR.
# For convenience, it can also be executed manually.
# Running the script without parameters, or with the --all-tests
# flag, causes all tests to be executed, in the right order.
# Use the flags --build-tests, --unit-tests and --integration-tests
# to run a specific set of tests.

source $(dirname $0)/../vendor/github.com/knative/test-infra/scripts/presubmit-tests.sh

function build_tests() {
  header "Running build tests"
  local result=0
  go build -v ./cmd/... ./pkg/... || result=1
  # "go build" on //test will fail with "no non-test Go files in ..."
  # See https://github.com/golang/go/issues/8279 for details
  # Workaround is to use "go test -run" with a non matching pattern
  go test -run=^$ -tags="e2e performance" ./test/... || result=1
  subheader "Checking autogenerated code is up-to-date"
  ./hack/verify-codegen.sh || result=1
  # Check that we don't have any forbidden licenses in our images.
  subheader "Checking for forbidden licenses"
  check_licenses ./cmd/* || result=1
  return ${result}
}

function unit_tests() {
  header "Running unit tests"
  report_go_test ./...
}

# We use the default integration test runner.

main $@
